@@ -1,8 +1,9 @@
 """RIOT pkg generator module."""
 
+import os
 import click
 
-from .common import render_source, generate
+from .common import load_and_check_params, check_overwrite, render_source
 
 
 PKG_PARAMS = {
@@ -17,7 +18,7 @@ PKG_PARAMS = {
     "description": {"args": ["Package short description"], "kwargs": {}},
 }
 
-PKG_PARAMS_LIST = ["modules", "packages", "features"]
+PKG_PARAMS_LIST = ["modules", "packages", "features_required"]
 
 PKG_FILES = {
     filename: None
@@ -30,24 +31,18 @@ PKG_RENAMED_FILES = {"pkg.mk": "{name}.mk"}
 def generate_pkg(interactive, config, riotbase):
     """Generate the code of a package."""
     group = "pkg"
-    params, output_dir = generate(
-        group,
-        PKG_PARAMS,
-        PKG_PARAMS_LIST,
-        PKG_FILES,
-        interactive,
-        config,
-        riotbase,
-        in_riot_dir="pkg",
+    params = load_and_check_params(
+        group, PKG_PARAMS, PKG_PARAMS_LIST, interactive, config, riotbase, "pkg",
     )
 
+    output_dir = os.path.join(riotbase, "pkg", params[group]["name"])
+    check_overwrite(output_dir)
+    render_source(params, group, PKG_FILES, output_dir)
     render_source(params, group, PKG_RENAMED_FILES, output_dir)
 
     click.echo(
         click.style(
-            "Package '{name}' generated in {output_dir} with success!".format(
-                name=params[group]["name"], output_dir=output_dir
-            ),
+            f"Package '{params[group]['name']}' generated in {output_dir} with success!",
             bold=True,
         )
     )
